@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Create Command Module."""
+
 from __future__ import annotations
 
 import logging
@@ -69,7 +70,7 @@ class Create(base.Base):
     type=click.Choice([str(s) for s in drivers()]),
     help=f"Name of driver to use. ({DEFAULT_DRIVER})",
 )
-def create(
+def create(  # noqa: PLR0913
     ctx: click.Context,
     /,
     scenario_name: list[str] | None,
@@ -78,9 +79,11 @@ def create(
     __all: bool,  # noqa: FBT001
     *,
     report: bool,
+    shared_inventory: bool,
 ) -> None:  # pragma: no cover
     """Use the provisioner to start the instances.
 
+    \f
     Args:
         ctx: Click context object holding commandline arguments.
         scenario_name: Name of the scenario to target.
@@ -88,13 +91,15 @@ def create(
         driver_name: Name of the Molecule driver to use.
         __all: Whether molecule should target scenario_name or all scenarios.
         report: Whether to show an after-run summary report.
-    """
+        shared_inventory: Whether the inventory should be shared between scenarios.
+    """  # noqa: D301
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {
         "subcommand": subcommand,
         "driver_name": driver_name,
         "report": report,
+        "shared_inventory": shared_inventory,
     }
 
     if __all:
