@@ -19,16 +19,24 @@
 #  DEALINGS IN THE SOFTWARE.
 """Idempotence Command Module."""
 
+from __future__ import annotations
+
 import logging
 import re
 
+from typing import TYPE_CHECKING
+
 import click
 
-from molecule import util
 from molecule.command import base
+from molecule.exceptions import ScenarioFailureError
 from molecule.text import strip_ansi_escape
 
 
+if TYPE_CHECKING:
+    from molecule.types import CommandArgs, MoleculeArgs
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -39,24 +47,32 @@ class Idempotence(base.Base):
     the scenario will be considered idempotent.
     """
 
-    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
-        """Execute the actions necessary to perform a `molecule idempotence` and returns None."""
+    def execute(self, action_args: list[str] | None = None) -> None:  # noqa: ARG002
+        """Execute the actions necessary to perform a `molecule idempotence`.
+
+        Args:
+            action_args: Arguments for this command. Unused.
+
+        Raises:
+            ScenarioFailureError: when idempotence fails to run.
+        """
         if not self._config.state.converged:
             msg = "Instances not converged.  Please converge instances first."
-            util.sysexit_with_message(msg)
+            raise ScenarioFailureError(message=msg)
 
-        output = self._config.provisioner.converge()
+        if self._config.provisioner:
+            output = self._config.provisioner.converge()
 
-        idempotent = self._is_idempotent(output)  # type: ignore[no-untyped-call]
-        if idempotent:
-            msg = "Idempotence completed successfully."
-            LOG.info(msg)
-        else:
-            details = "\n".join(self._non_idempotent_tasks(output))  # type: ignore[no-untyped-call]
-            msg = f"Idempotence test failed because of the following tasks:\n{details}"
-            util.sysexit_with_message(msg)
+            idempotent = self._is_idempotent(output)
+            if idempotent:
+                msg = "Idempotence completed successfully."
+                LOG.info(msg)
+            else:
+                details = "\n".join(self._non_idempotent_tasks(output))
+                msg = f"Idempotence test failed because of the following tasks:\n{details}"
+                raise ScenarioFailureError(message=msg)
 
-    def _is_idempotent(self, output):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
+    def _is_idempotent(self, output: str) -> bool:
         """Parse the output of the provisioning for changed and returns a bool.
 
         Args:
@@ -73,7 +89,7 @@ class Idempotence(base.Base):
 
         return not bool(changed)
 
-    def _non_idempotent_tasks(self, output):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
+    def _non_idempotent_tasks(self, output: str) -> list[str]:
         """Parse the output to identify the non idempotent tasks.
 
         Args:
@@ -87,7 +103,7 @@ class Idempotence(base.Base):
         output = re.sub(r"\n\s*\n*", "\n", output)
 
         # Remove ansi escape sequences.
-        output = strip_ansi_escape(output)  # type: ignore[no-untyped-call]
+        output = strip_ansi_escape(output)
 
         # Split the output into a list and go through it.
         output_lines = output.split("\n")
@@ -106,20 +122,41 @@ class Idempotence(base.Base):
 
 @base.click_command_ex()
 @click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
+@base.click_command_options
 @click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
-def idempotence(ctx, scenario_name, ansible_args):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
+def idempotence(  # noqa: PLR0913
+    ctx: click.Context,
+    scenario_name: list[str] | None,
+    exclude: list[str],
+    __all: bool,  # noqa: FBT001
+    *,
+    ansible_args: tuple[str, ...],
+    report: bool,
+    shared_inventory: bool,
+) -> None:  # pragma: no cover
     """Use the provisioner to configure the instances.
 
     After parse the output to determine idempotence.
-    """
-    args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args = {"subcommand": subcommand}
 
-    base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args)
+    \f
+    Args:
+        ctx: Click context object holding commandline arguments.
+        scenario_name: Name of the scenario to target.
+        exclude: Name of the scenarios to avoid targeting.
+        __all: Whether molecule should target scenario_name or all scenarios.
+        ansible_args: Arguments to forward to Ansible.
+        report: Whether to show an after-run summary report.
+        shared_inventory: Whether the inventory should be shared between scenarios.
+    """  # noqa: D301
+    args: MoleculeArgs = ctx.obj.get("args")
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
+    command_args: CommandArgs = {
+        "subcommand": subcommand,
+        "report": report,
+        "shared_inventory": shared_inventory,
+    }
+
+    if __all:
+        scenario_name = None
+
+    base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args, exclude)
