@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Login Command Module."""
+
 from __future__ import annotations
 
 import logging
@@ -29,8 +30,9 @@ from typing import TYPE_CHECKING
 
 import click
 
-from molecule import scenarios, util
+from molecule import scenarios
 from molecule.command import base
+from molecule.exceptions import MoleculeError
 
 
 if TYPE_CHECKING:
@@ -79,15 +81,12 @@ class Login(base.Base):
                     "which with --host.\n\n"
                     f"Available hosts:\n{host_list}"
                 )
-                util.sysexit_with_message(msg)
+                raise MoleculeError(msg)
         match = [x for x in hosts if x.startswith(hostname)]
         if len(match) == 0:
-            msg = (
-                f"There are no hosts that match '{hostname}'.  You "
-                "can only login to valid hosts."
-            )
-            util.sysexit_with_message(msg)
-        elif len(match) != 1:
+            msg = f"There are no hosts that match '{hostname}'.  You can only login to valid hosts."
+            raise MoleculeError(msg)
+        if len(match) != 1:
             # If there are multiple matches, but one of them is an exact string
             # match, assume this is the one they're looking for and use it.
             if hostname in match:
@@ -98,7 +97,7 @@ class Login(base.Base):
                     "can only login to one at a time.\n\n"
                     f"Available hosts:\n{host_list}"
                 )
-                util.sysexit_with_message(msg)
+                raise MoleculeError(msg)
 
         return match[0]
 
@@ -137,11 +136,12 @@ def login(
 ) -> None:  # pragma: no cover
     """Log in to one instance.
 
+    \f
     Args:
         ctx: Click context object holding commandline arguments.
         host: Host to access.
         scenario_name: Name of the scenario to target.
-    """
+    """  # noqa: D301
     args = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {"subcommand": subcommand, "host": host}
