@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Config Module."""
+
 from __future__ import annotations
 
 import copy
@@ -30,12 +31,12 @@ from typing import TYPE_CHECKING
 from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
-from packaging.version import Version
 
 from molecule import api, interpolation, platforms, scenario, state, util
 from molecule.app import get_app
 from molecule.data import __file__ as data_module
 from molecule.dependency import ansible_galaxy, shell
+from molecule.exceptions import MoleculeError
 from molecule.model import schema_v3
 from molecule.provisioner import ansible
 from molecule.util import boolean
@@ -45,6 +46,8 @@ if TYPE_CHECKING:
     from collections.abc import MutableMapping
     from typing import Literal
 
+    from packaging.version import Version
+
     from molecule.dependency.base import Base as Dependency
     from molecule.driver.base import Driver
     from molecule.state import State
@@ -53,8 +56,9 @@ if TYPE_CHECKING:
 
 
 LOG = logging.getLogger(__name__)
-MOLECULE_DEBUG = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
-MOLECULE_VERBOSITY = int(os.environ.get("MOLECULE_VERBOSITY", 0))
+MOLECULE_PARALLEL: bool = boolean(os.environ.get("MOLECULE_PARALLEL", ""))
+MOLECULE_DEBUG: bool = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
+MOLECULE_VERBOSITY: int = int(os.environ.get("MOLECULE_VERBOSITY", "0"))
 MOLECULE_DIRECTORY = "molecule"
 MOLECULE_FILE = "molecule.yml"
 MOLECULE_KEEP_STRING = "MOLECULE_"
@@ -134,20 +138,6 @@ class Config:
         """Write config file to filesystem."""
         util.write_file(self.config_file, util.safe_dump(self.config))
 
-    @property
-    def ansible_collections_path(
-        self,
-    ) -> str:
-        """Return collection path variable for current version of Ansible.
-
-        Returns:
-            The correct ansible collection path to use.
-        """
-        # https://github.com/ansible/ansible/pull/70007
-        if self.runtime.version >= Version("2.10.0.dev0"):
-            return "ANSIBLE_COLLECTIONS_PATH"
-        return "ANSIBLE_COLLECTIONS_PATHS"
-
     @property
     def config_file(self) -> str:
         """Path to the config file.
@@ -167,6 +157,15 @@ class Config:
         """
         return self.command_args.get("parallel", False)
 
+    @property
+    def shared_inventory(self) -> bool:
+        """Should molecule share ephemeral data.
+
+        Returns:
+            Whether molecule should share ephemeral data.
+        """
+        return self.command_args.get("shared_inventory", False)
+
     @property
     def platform_name(self) -> str | None:
         """Configured platform.
@@ -308,6 +307,9 @@ class Config:
 
         Returns:
             The driver for this scenario.
+
+        Raises:
+            MoleculeError: when the specified driver cannot be found.
         """
         driver_name = self._get_driver_name()
         driver = None
@@ -315,13 +317,22 @@ class Config:
         api_drivers = api.drivers(config=self)
         if driver_name not in api_drivers:
             msg = f"Failed to find driver {driver_name}. Please ensure that the driver is correctly installed."
-            util.sysexit_with_message(msg)
+            raise MoleculeError(msg)
 
         driver = api_drivers[driver_name]
         driver.name = driver_name
 
         return driver
 
+    @property
+    def executor(self) -> str:
+        """Return playbook executor.
+
+        Returns:
+            The executor backend.
+        """
+        return self.config.get("executor", {}).get("backend", "ansible-playbook")
+
     @property
     def env(self) -> dict[str, str]:
         """Environment variables.
@@ -442,14 +453,14 @@ class Config:
                 f"Instance(s) were created with the '{driver_name}' driver, but the "
                 f"subcommand is using '{driver_from_cli}' driver."
             )
-            util.sysexit_with_message(msg)
+            raise MoleculeError(msg)
 
         if driver_from_state_file and driver_name not in api.drivers():
             msg = (
                 f"Driver '{driver_name}' from state-file "
                 f"'{self.state.state_file}' is not available."
             )
-            util.sysexit_with_message(msg)
+            raise MoleculeError(msg)
 
         if driver_from_scenario != driver_name:
             msg = (
@@ -544,7 +555,7 @@ class Config:
             return i.interpolate(stream, keep_string)
         except interpolation.InvalidInterpolation as e:
             msg = f"parsing config file '{self.molecule_file}'.\n\n{e.place}\n{e.string}"
-            util.sysexit_with_message(msg)
+            raise MoleculeError(msg) from e
         return ""
 
     def _get_defaults(self) -> ConfigData:
@@ -570,6 +581,9 @@ class Config:
                 "ssh_connection_options": [],
                 "safe_files": [],
             },
+            "executor": {
+                "backend": "ansible-playbook",
+            },
             "platforms": [],
             "prerun": True,
             "role_name_check": 0,
@@ -641,14 +655,18 @@ class Config:
         }
 
     def _validate(self) -> None:
-        """Validate molecule file."""
+        """Validate molecule file.
+
+        Raises:
+            MoleculeError: when config file fails to validate.
+        """
         msg = f"Validating schema {self.molecule_file}."
         LOG.debug(msg)
 
         errors = schema_v3.validate(self.config)
         if errors:
             msg = f"Failed to validate {self.molecule_file}\n\n{errors}"
-            util.sysexit_with_message(msg)
+            raise MoleculeError(msg)
 
 
 def molecule_directory(path: str | Path) -> str:
